library(ape)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")

fragments <- c("its", "rbcl", "trnl", "matk", "petd") # fragile

treesp <- read.table("../../data/buxineae_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup"]
outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier"]

for (f in fragments) {
cat(f, "\n")
assign(f, read.dna(paste0("32_alignments_trimmed_gapcoded/", f, ".fasta"), format="fasta"))
LAB <- sub("__.*$", "", labels(get(f)))
OUT <- labels(get(f))[LAB %in% outgroups]
EXC <- labels(get(f))[LAB %in% outliers] # is not used
tree <- Root1(nj(dist.dna(get(f))), OUT, resolve.root=T)
 pdf(paste("50_technical_trees/", DATE, "_buxineae_", f, "_single_marker_nj_tree.pdf", sep=""), width=12, height=24)
 par(mar=c(0,0,0,0))
 plot(tree)
 mtext(f, line=-3, font=2)
 dev.off()
}
