library(shipunov)
library(ips) # this package contains raxml() function to call RAxML from within R

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S") # timestamp
conc <- read.dna("40_concatenated/its_full.fasta", format="fasta", as.character=TRUE)

names <- read.table("40_concatenated/its_full_names.txt", sep="\t", as.is=TRUE)
nonames <- Recode(row.names(conc), names[, 1], names[, 3])
row.names(conc) <- Recode(row.names(conc), names[, 1], names[, 2])
conc <- conc[nonames == 1, ]
conc <- as.DNAbin(conc)

OUT <- c("Trochodendron_aralioides__AF266105", "Tetracentron_sinense__JF978888")

setwd("60_raxml_working") # go to RAxML working directory
tr <- raxml(conc, m="GTRGAMMAI", # change the model if needed
 f="a", # change RAxML algorithm if needed
 N=1000, # change bootstrap options if needed
 p=1234, x=1234, exec="raxmlHPC", # change name of RAxML binary; on Windows, you will _need_ to change it
 outgroup=OUT)
setwd("..") # go out of RAxML working directory

## print "bipartitions" tree to PDF
pdf(paste0("99_ml_trees/", DATE, "_its_full_raxml_buxineae.pdf"), height=12, width=16) # change PDF size if needed
oldpar <- par(mar=rep(0, 4))
plot(tr$bipartitions)
nodelabels(tr$bipartitions$node.label, frame="none", bg="transparent", adj=-0.1)
mtext("its_full RAxML", font=2, line=-1)
add.scale.bar()
dev.off()

## also save it as Newick
tr$node.label[tr$node.label == "NA"] <- "" # useful for some Newick reading software
write.tree(tr$bipartitions, file=paste0("99_ml_trees/", DATE, "_its_full_raxml_buxineae.tre"))
